==> enhanced-3.2.1.tar.gz: enhanced-3.2.1/README.md <==
# enhanced

![enhanced banner](https://github.com/interactions-py/enhanced/blob/main/src/enhanced_wide.png?raw=true)

[![Discord](https://img.shields.io/discord/924871439776108544?color=blue&label=discord&style=for-the-badge)](https://discord.gg/Y78bpT5aNv) [![PyPI - Downloads](https://img.shields.io/pypi/dm/enhanced?color=blue&style=for-the-badge)](https://pypi.org/project/enhanced/)

Enhanced interactions for interactions.py

Join the [Discord server](https://discord.gg/Y78bpT5aNv) to ask questions, get help, or to discuss the project!

## Installation

```bash
pip install -U enhanced
```

## Table of Contents

- [Installation](#installation)
- [Table of Contents](#table-of-contents)
- [What is this library?](#what-is-this-library)
- [Guide](#guide)
- [Documentation](#documentation)

## What is this library?

This is `enhanced`, a library for `interactions.py` which modifies interactions, and adds useful helper functions.

It simplifies the process of creating commands, and provides an easy and organized way to make subcommands. Enhanced callbacks are also implemented, which allow for more advanced functionality. Enhanced components are also implemented, which allow for better looking code. A cooldown system is also implemented, which allows for commands to have a cooldown.

## Guide

- [Home](https://github.com/interactions-py/enhanced/wiki)
- [Subcommands](https://github.com/interactions-py/enhanced/wiki/Subcommands)
- [Enhanced commands](https://github.com/interactions-py/enhanced/wiki/Better-commands)
- [Enhanced components](https://github.com/interactions-py/enhanced/wiki/Better-components)
- [Enhanced callbacks](https://github.com/interactions-py/enhanced/wiki/Better-callbacks)
- [Cooldown](https://github.com/interactions-py/enhanced/wiki/Cooldown)

## Documentation

[![API Reference](https://img.shields.io/badge/API-Reference-blue.svg)](https://github.com/interactions-py/enhanced/wiki/API-Reference)

==> enhanced-3.3.0rc2.tar.gz: enhanced-3.3.0rc2/README.md <==
# enhanced

![enhanced banner](https://github.com/interactions-py/enhanced/blob/main/src/enhanced_banner.png?raw=true)

[![Discord](https://img.shields.io/discord/924871439776108544?color=blue&label=discord&style=for-the-badge)](https://discord.gg/Y78bpT5aNv) [![PyPI - Downloads](https://img.shields.io/pypi/dm/enhanced?color=blue&style=for-the-badge)](https://pypi.org/project/enhanced/)

Enhanced interactions for interactions.py

Join the [Discord server](https://discord.gg/Y78bpT5aNv) to ask questions, get help, or to discuss the project!

## Installation

```bash
pip install -U enhanced
```

## Table of Contents

- [Installation](#installation)
- [Table of Contents](#table-of-contents)
- [What is this library?](#what-is-this-library)
- [Guide](#guide)
- [Documentation](#documentation)

## What is this library?

This is `enhanced`, a library for `interactions.py` which modifies interactions, and adds useful helper functions.

It simplifies the process of creating commands, and provides an easy and organized way to make subcommands. Enhanced callbacks are also implemented, which allow for more advanced functionality. Enhanced components are also implemented, which allow for better looking code. A cooldown system is also implemented, which allows for commands to have a cooldown.

## Guide

- [Home](https://github.com/interactions-py/enhanced/wiki)
- [Subcommands](https://github.com/interactions-py/enhanced/wiki/Subcommands)
- [Enhanced commands](https://github.com/interactions-py/enhanced/wiki/Enhanced-commands)
- [Enhanced components](https://github.com/interactions-py/enhanced/wiki/Enhanced-components)
- [Enhanced callbacks](https://github.com/interactions-py/enhanced/wiki/Enhanced-callbacks)
- [Cooldown](https://github.com/interactions-py/enhanced/wiki/Cooldown)

## Documentation

[![API Reference](https://img.shields.io/badge/API-Reference-blue.svg)](https://github.com/interactions-py/enhanced/wiki/API-Reference)
